searchNodes=[{"doc":"Functions to make working with prefixes easier, especially IPv4 and IPv6 prefixes. Pfx defines a prefix as a struct with a number of bits and a maximum maxlen length. Hence a Pfx struct represents some domain-specific value, like an IPv4/6 address or network, a MAC address, a MAC OUI range or something else entirely. A Pfx struct can be created from: a bitstring/0 and a non_neg_integer/0 for the maximum length, a Pfx.ip_address/0 , a Pfx.ip_prefix/0 , or a binary/0 denoting an IP prefix in CIDR-notation. The first option allows for the creation of any sort of prefix, the latter three yield either an IPv4 or IPv6 prefix. Several functions, like Pfx.unique_local?/1 are more IP oriented, and are included along with the more generic Pfx functions (like Pfx.cut/3 ) in order to have one module to rule them all. Functions generally accept all four representations and yield their result in the same fashion, if possible: iex&gt; hosts ( &quot;10.10.10.0/30&quot; ) [ &quot;10.10.10.0&quot; , &quot;10.10.10.1&quot; , &quot;10.10.10.2&quot; , &quot;10.10.10.3&quot; ] iex&gt; hosts ( { { 10 , 10 , 10 , 0 } , 30 } ) [ { { 10 , 10 , 10 , 0 } , 32 } , { { 10 , 10 , 10 , 1 } , 32 } , { { 10 , 10 , 10 , 2 } , 32 } , { { 10 , 10 , 10 , 3 } , 32 } ] iex&gt; hosts ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 0 :: 6 &gt;&gt; , maxlen : 32 } ) [ % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 0 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 1 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 2 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 3 &gt;&gt; , maxlen : 32 } , ] # adopt representation of first argument iex&gt; band ( { 10 , 10 , 10 , 1 } , &quot;255.255.255.0&quot; ) { 10 , 10 , 10 , 0 } iex&gt; multicast? ( &quot;ff00::1&quot; ) true Validity The Pfx.new/2 function will silently clip the provided bits -string to maxlen -bits when needed, since a Pfx struct named pfx is valid, iff: bit_size(pfx.bits) &lt;= pfx.maxlen , and where pfx.maxlen is a non_neg_integer/0 Keep that in mind when instantiating directly or updating a Pfx , otherwise functions will choke on it. Same goes for Pfx.ip_address/0 representations, which must be a valid :inet.ip_address() , representing either an IPv4 or IPv6 address through a tuple of four 8 -bit wide numbers or eight 16 -bit wide numbers. If used as the first element in a Pfx.ip_prefix/0 tuple, the second element is interpreted as the mask, used to clip the bitstring when creating the Pfx struct. IPv4 masks must be in range 0..32 and IPv6 masks in range 0..128 . The resulting Pfx will have its maxlen set to 32 for IPv4 tuples and 128 for IPv6 tuples. Last but not least, a binary is interpreted as a string in CIDR-notation for some IPv4/IPv6 address or prefix. Ancient tradition Pfx.new/1 accepts CIDR-strings which are ultimately processed using erlang's :inet.parse_address which, at the time of writing, still honors the ancient linux tradition of injecting zero's when presented with less than four IPv4 digits in a CIDR string. # &quot;d&quot; -&gt; &quot;0.0.0.d&quot; iex&gt; new ( &quot;10&quot; ) |&gt; format ( ) &quot;0.0.0.10&quot; iex&gt; new ( &quot;10/8&quot; ) |&gt; format ( ) &quot;0.0.0.0/8&quot; # &quot;d1.d2&quot; -&gt; &quot;d1.0.0.d2&quot; iex&gt; new ( &quot;10.10&quot; ) |&gt; format ( ) &quot;10.0.0.10&quot; iex&gt; new ( &quot;10.10/16&quot; ) |&gt; format ( ) &quot;10.0.0.0/16&quot; # &quot;d1.d2.d3&quot; -&gt; &quot;d1.d2.0.d3&quot; iex&gt; new ( &quot;10.10.10&quot; ) |&gt; format ( ) &quot;10.10.0.10&quot; iex&gt; new ( &quot;10.10.10/24&quot; ) |&gt; format ( ) &quot;10.10.0.0/24&quot; Bottom line: never go short, you may be unpleasantly surprised. Limitations A lot of Pfx -functions convert the Pfx.bits bitstring to an integer using Pfx.cast/1 , before performing some, often Bitwise -related, calculation on them. Luckily Elixir can handle pretty large numbers which seem mostly limited by the available system memory. Other functions, like Pfx.digits/2 return a tuple with numbers and are so limited by the maximum number of elements in a tuple (~16M+). So if you're taking this somewhere far, far away, heed these limitations before leaving. Also, everything is done in Elixir with no extra, external dependencies. Usually fast enough, but if you really feel the need for speed, you might want to look elsewhere. Ayway, enough downplay, here are some more examples. Examples # IANA&#39;s OUI range 00-00-5e-xx-xx-xx iex&gt; new ( &lt;&lt; 0x00 , 0x00 , 0x5e &gt;&gt; , 48 ) % Pfx { bits : &lt;&lt; 0 , 0 , 94 &gt;&gt; , maxlen : 48 } # IANA&#39;s assignment for the VRRP MAC address range 00-00-5e-00-01-{VRID} iex&gt; vrrp_mac_range = new ( &lt;&lt; 0x00 , 0x00 , 0x5e , 0x00 , 0x01 &gt;&gt; , 48 ) % Pfx { bits : &lt;&lt; 0 , 0 , 94 , 0 , 1 &gt;&gt; , maxlen : 48 } iex&gt; iex&gt; vrrp_mac = new ( &lt;&lt; 0x00 , 0x00 , 0x5e , 0x00 , 0x01 , 0x0f &gt;&gt; , 48 ) % Pfx { bits : &lt;&lt; 0 , 0 , 94 , 0 , 1 , 15 &gt;&gt; , maxlen : 48 } iex&gt; iex&gt; member? ( vrrp_mac , vrrp_mac_range ) true iex&gt; cut ( vrrp_mac , 47 , - 8 ) |&gt; cast ( ) 15 # IPv4 examples iex&gt; new ( &lt;&lt; 10 , 10 , 10 &gt;&gt; , 32 ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } iex&gt; new ( &quot;10.10.10.0/24&quot; ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } iex&gt; new ( { 10 , 10 , 10 , 10 } ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 10 &gt;&gt; , maxlen : 32 } iex&gt; new ( { { 10 , 10 , 10 , 10 } , 24 } ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } # IPv6 examples iex&gt; new ( &lt;&lt; 44252 :: 16 , 6518 :: 16 &gt;&gt; , 128 ) % Pfx { bits : &lt;&lt; 0xACDC :: 16 , 0x1976 :: 16 &gt;&gt; , maxlen : 128 } iex&gt; new ( &quot;acdc:1976::/32&quot; ) % Pfx { bits : &lt;&lt; 44252 :: 16 , 6518 :: 16 &gt;&gt; , maxlen : 128 } iex&gt; new ( { { 44252 , 6518 , 0 , 0 , 0 , 0 , 0 , 0 } , 32 } ) % Pfx { bits : &lt;&lt; 0xACDC :: 16 , 0x1976 :: 16 &gt;&gt; , maxlen : 128 } Pfx.t/0 implements the String.Chars protocol with some defaults for prefixes that formats prefixes with: maxlen: 32 as an IPv4 CIDR string, maxlen: 48 as a MAC address string and maxlen: 128 as an IPv6 CIDR string Other maxlen 's will simply come out as a series of 8-bit numbers joined by &quot;.&quot; followed by /num_of_bits . The latter is omitted if equal to pfx.bits length. If other formatting is required, use the Pfx.format/2 function, which takes some options that help shape the string representation for a Pfx struct. # a subnet iex&gt; &quot; \#{ new ( &lt;&lt; 10 , 11 , 12 &gt;&gt; , 32 ) } &quot; &quot;10.11.12.0/24&quot; # an address iex&gt; &quot; \#{ new ( &lt;&lt; 10 , 11 , 12 , 13 &gt;&gt; , 32 ) } &quot; &quot;10.11.12.13&quot; # an ipv6 prefix iex&gt; &quot; \#{ new ( &lt;&lt; 0xACDC :: 16 , 0x1976 :: 16 &gt;&gt; , 128 ) } &quot; &quot;acdc:1976:0:0:0:0:0:0/32&quot; # a MAC address iex&gt; &quot; \#{ new ( &lt;&lt; 0xA1 , 0xB2 , 0xC3 , 0xD4 , 0xE5 , 0xF6 &gt;&gt; , 48 ) } &quot; &quot;A1:B2:C3:D4:E5:F6&quot; # just 8-bit numbers and mask length iex&gt; &quot; \#{ new ( &lt;&lt; 1 , 2 , 3 , 4 , 5 &gt;&gt; , 64 ) } &quot; &quot;1.2.3.4.5.0.0.0/40&quot; # an ip4 address formatted as a string of bits iex&gt; new ( &lt;&lt; 1 , 2 , 3 , 4 &gt;&gt; , 32 ) |&gt; format ( width : 1 , unit : 8 ) &quot;00000001.00000010.00000011.00000100&quot; A Pfx.t/0 struct is also enumerable: iex&gt; pfx = new ( &quot;10.10.10.0/30&quot; ) iex&gt; for ip &lt;- pfx do &quot; \#{ ip } &quot; end [ &quot;10.10.10.0&quot; , &quot;10.10.10.1&quot; , &quot;10.10.10.2&quot; , &quot;10.10.10.3&quot; ] Functions are sometimes IP specific, like: iex&gt; dns_ptr ( &quot;acdc:1975::b1ba:2021&quot; ) &quot;1.2.0.2.a.b.1.b.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.5.7.9.1.c.d.c.a.ip6.arpa&quot; iex&gt; teredo ( &quot;2001:0000:4136:e378:8000:63bf:3fff:fdd2&quot; ) %{ server : &quot;65.54.227.120&quot; , client : &quot;192.0.2.45&quot; , port : 40000 , flags : { 1 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } , prefix : &quot;2001:0000:4136:e378:8000:63bf:3fff:fdd2&quot; } But most of the times, functions have generic names, since they apply to all sorts of prefixes, e.g. iex&gt; partition ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } , 26 ) [ % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 0 :: size ( 2 ) &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 1 :: size ( 2 ) &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 2 :: size ( 2 ) &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 3 :: size ( 2 ) &gt;&gt; , maxlen : 32 } ] The Pfx.new/1 and Pfx.new/2 always return a Pfx.t/0 struct, but most other functions will return their results in the same representation they were given. So the above could also be done as: iex&gt; partition ( &quot;10.10.10.0/24&quot; , 26 ) [ &quot;10.10.10.0/26&quot; , &quot;10.10.10.64/26&quot; , &quot;10.10.10.128/26&quot; , &quot;10.10.10.192/26&quot; ] # or iex&gt; partition ( { { 10 , 10 , 10 , 0 } , 24 } , 26 ) [ { { 10 , 10 , 10 , 0 } , 26 } , { { 10 , 10 , 10 , 64 } , 26 } , { { 10 , 10 , 10 , 128 } , 26 } , { { 10 , 10 , 10 , 192 } , 26 } ]","ref":"Pfx.html","title":"Pfx","type":"module"},{"doc":"A bitwise AND of two prefix/0 's. Both prefixes must have the same maxlen . The resulting prefix will have the same number of bits as the first argument. Examples iex&gt; band ( &quot;10.10.10.10&quot; , &quot;255.255.0.0&quot; ) &quot;10.10.0.0&quot; iex&gt; band ( &quot;10.10.10.0/24&quot; , &quot;255.255.0.0&quot; ) &quot;10.10.0.0/24&quot; iex&gt; x = new ( &lt;&lt; 128 , 129 , 130 , 131 &gt;&gt; , 32 ) iex&gt; y = new ( &lt;&lt; 255 , 255 &gt;&gt; , 32 ) iex&gt; iex&gt; band ( x , y ) % Pfx { bits : &lt;&lt; 128 , 129 , 0 , 0 &gt;&gt; , maxlen : 32 } iex&gt; iex&gt; band ( y , x ) % Pfx { bits : &lt;&lt; 128 , 129 &gt;&gt; , maxlen : 32 } # results adopt the format of the first argument iex&gt; band ( &quot;1.2.3.4&quot; , { 255 , 255 , 0 , 0 } ) &quot;1.2.0.0&quot; iex&gt; band ( { 1 , 2 , 3 , 4 } , &quot;255.255.0.0&quot; ) { 1 , 2 , 0 , 0 } iex&gt; band ( { { 1 , 2 , 3 , 4 } , 24 } , { 255 , 255 , 0 , 0 } ) { { 1 , 2 , 0 , 0 } , 24 } # honoring the ancient tradition iex&gt; band ( &quot;1.2.3.4&quot; , &quot;255.255&quot; ) &quot;1.0.0.4&quot;","ref":"Pfx.html#band/2","title":"Pfx.band/2","type":"function"},{"doc":"Return pfx prefix's bit-value at given position . A bit position is a 0 -based index from the left with range 0..maxlen-1 . A negative bit position is taken relative to Pfx.maxlen . A actual bit position in the range of bit_size(pfx.bits) .. pfx.maxlen - 1 always yields 0 . Examples iex&gt; bit ( % Pfx { bits : &lt;&lt; 1 , 2 &gt;&gt; , maxlen : 32 } , 14 ) 1 iex&gt; bit ( &quot;1.2.0.0/16&quot; , 14 ) 1 iex&gt; bit ( { 1 , 2 , 0 , 0 } , 14 ) 1 iex&gt; bit ( { { 1 , 2 , 0 , 0 } , 16 } , 14 ) 1 # &#39;missing&#39; bits inside the prefix are deemed to be `0` iex&gt; bit ( &quot;1.2.0.0/16&quot; , 24 ) 0 iex&gt; bit ( &quot;1.2.0.0/16&quot; , - 8 ) # same bit, 32 - 8 = 24 0 # errors out on invalid positions iex&gt; bit ( &quot;255.255.255.255&quot; , 33 ) ** (ArgumentError) invalid bit position: 33 iex&gt; bit ( &quot;10.10.0.0/16&quot; , - 33 ) ** (ArgumentError) invalid bit position: -33","ref":"Pfx.html#bit/2","title":"Pfx.bit/2","type":"function"},{"doc":"Return the concatenation of 1 or more series of bits of the given pfx . Example iex&gt; bits ( % Pfx { bits : &lt;&lt; 1 , 2 , 3 , 4 &gt;&gt; , maxlen : 32 } , [ { 0 , 8 } , { - 1 , - 8 } ] ) &lt;&lt; 1 , 4 &gt;&gt; iex&gt; bits ( { { 1 , 2 , 3 , 4 } , 32 } , [ { 0 , 8 } , { - 1 , - 8 } ] ) &lt;&lt; 1 , 4 &gt;&gt; iex&gt; bits ( { 1 , 2 , 3 , 4 } , [ { 0 , 8 } , { - 1 , - 8 } ] ) &lt;&lt; 1 , 4 &gt;&gt; iex&gt; bits ( &quot;1.2.3.4&quot; , [ { 0 , 8 } , { - 1 , - 8 } ] ) &lt;&lt; 1 , 4 &gt;&gt; iex&gt; bits ( &quot;1.2.3.4/24&quot; , [ { 0 , 8 } , { - 1 , - 8 } ] ) &lt;&lt; 1 , 0 &gt;&gt;","ref":"Pfx.html#bits/2","title":"Pfx.bits/2","type":"function"},{"doc":"Return a series of bits for given pfx , starting bit position &amp; length . Negative position 's are relative to the end of the pfx.bits bitstring, while negative length will collect bits going left instead of to the right. Note that the bit at given position is always included in the result regardless of direction. Finally, a length of 0 results in an empty bitstring. Examples # first byte iex&gt; bits ( % Pfx { bits : &lt;&lt; 128 , 0 , 0 , 1 &gt;&gt; , maxlen : 32 } , 0 , 8 ) &lt;&lt; 128 &gt;&gt; # same as iex&gt; bits ( % Pfx { bits : &lt;&lt; 128 , 0 , 0 , 1 &gt;&gt; , maxlen : 32 } , 7 , - 8 ) &lt;&lt; 128 &gt;&gt; # last two bytes iex&gt; bits ( &quot;128.0.128.1&quot; , 16 , 16 ) &lt;&lt; 128 , 1 &gt;&gt; iex&gt; bits ( { 128 , 0 , 128 , 1 } , 16 , 16 ) # same &lt;&lt; 128 , 1 &gt;&gt; iex&gt; bits ( { 128 , 0 , 128 , 1 } , 31 , - 16 ) # same &lt;&lt; 128 , 1 &gt;&gt; iex&gt; bits ( { { 128 , 0 , 128 , 1 } , 32 } , 31 , - 16 ) # same &lt;&lt; 128 , 1 &gt;&gt; # missing bits are filled in as `0` iex&gt; x = new ( &lt;&lt; 128 &gt;&gt; , 32 ) iex&gt; bits ( x , 0 , 32 ) &lt;&lt; 128 , 0 , 0 , 0 &gt;&gt; iex&gt; x = new ( &lt;&lt; 128 &gt;&gt; , 32 ) iex&gt; bits ( x , 0 , 16 ) &lt;&lt; 128 , 0 &gt;&gt; iex&gt; x = new ( &lt;&lt; 128 &gt;&gt; , 32 ) iex&gt; bits ( x , 15 , - 16 ) &lt;&lt; 128 , 0 &gt;&gt; # the last 5 bits iex&gt; x = new ( &lt;&lt; 255 &gt;&gt; , 32 ) iex&gt; bits ( x , 7 , - 5 ) &lt;&lt; 0b11111 :: size ( 5 ) &gt;&gt;","ref":"Pfx.html#bits/3","title":"Pfx.bits/3","type":"function"},{"doc":"A bitwise NOT of the pfx.bits . Results are returned in the same representation as given pfx . Examples iex&gt; new ( &lt;&lt; 255 , 255 , 0 , 0 &gt;&gt; , 32 ) |&gt; bnot ( ) % Pfx { bits : &lt;&lt; 0 , 0 , 255 , 255 &gt;&gt; , maxlen : 32 } iex&gt; new ( &lt;&lt; 255 , 0 &gt;&gt; , 32 ) |&gt; bnot ( ) % Pfx { bits : &lt;&lt; 0 , 255 &gt;&gt; , maxlen : 32 } iex&gt; bnot ( &quot;255.255.0.0&quot; ) &quot;0.0.255.255&quot; iex&gt; bnot ( { 255 , 255 , 0 , 0 } ) { 0 , 0 , 255 , 255 } iex&gt; bnot ( { { 255 , 255 , 0 , 0 } , 32 } ) { { 0 , 0 , 255 , 255 } , 32 }","ref":"Pfx.html#bnot/1","title":"Pfx.bnot/1","type":"function"},{"doc":"A bitwise OR of two prefixes. Both prefixes must have the same maxlen . Examples # same sized `bits` iex&gt; x = new ( &lt;&lt; 10 , 11 , 12 , 13 &gt;&gt; , 32 ) iex&gt; y = new ( &lt;&lt; 0 , 0 , 255 , 255 &gt;&gt; , 32 ) iex&gt; bor ( x , y ) % Pfx { bits : &lt;&lt; 10 , 11 , 255 , 255 &gt;&gt; , maxlen : 32 } # same `maxlen` but differently sized `bits`: missing bits are considered to be `0` iex&gt; x = new ( &lt;&lt; 10 , 11 , 12 , 13 &gt;&gt; , 32 ) iex&gt; y = new ( &lt;&lt; 255 , 255 &gt;&gt; , 32 ) iex&gt; bor ( x , y ) % Pfx { bits : &lt;&lt; 255 , 255 , 12 , 13 &gt;&gt; , maxlen : 32 } iex&gt; bor ( &quot;1.2.3.4&quot; , &quot;0.0.255.0&quot; ) &quot;1.2.255.4&quot; iex&gt; bor ( { 1 , 2 , 3 , 4 } , &quot;0.0.255.0&quot; ) { 1 , 2 , 255 , 4 } iex&gt; bor ( { { 1 , 2 , 3 , 4 } , 16 } , { 0 , 255 , 255 , 0 } ) { { 1 , 255 , 0 , 0 } , 16 }","ref":"Pfx.html#bor/2","title":"Pfx.bor/2","type":"function"},{"doc":"Returns the broadcast prefix (full address) for given pfx . The result is in the same format as pfx . Examples iex&gt; broadcast ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 255 &gt;&gt; , maxlen : 32 } iex&gt; broadcast ( { { 10 , 10 , 10 , 1 } , 30 } ) { { 10 , 10 , 10 , 3 } , 32 } # a full address is its own broadcast address iex&gt; broadcast ( { 10 , 10 , 10 , 1 } ) { 10 , 10 , 10 , 1 } iex&gt; broadcast ( &quot;10.10.0.0/16&quot; ) &quot;10.10.255.255&quot; iex&gt; broadcast ( % Pfx { bits : &lt;&lt; 0xacdc :: 16 , 0x1976 :: 16 &gt;&gt; , maxlen : 128 } ) % Pfx { bits : &lt;&lt; 0xACDC :: 16 , 0x1976 :: 16 , - 1 :: 96 &gt;&gt; , maxlen : 128 }","ref":"Pfx.html#broadcast/1","title":"Pfx.broadcast/1","type":"function"},{"doc":"Rotate the pfx.bits by n positions. Positive n rotates right, negative rotates left. Note that the length of the resulting pfx.bits stays the same. Examples iex&gt; brot ( % Pfx { bits : &lt;&lt; 1 , 2 , 3 , 4 &gt;&gt; , maxlen : 32 } , 8 ) % Pfx { bits : &lt;&lt; 4 , 1 , 2 , 3 &gt;&gt; , maxlen : 32 } iex&gt; new ( &lt;&lt; 1 , 2 , 3 , 4 &gt;&gt; , 32 ) |&gt; brot ( - 8 ) % Pfx { bits : &lt;&lt; 2 , 3 , 4 , 1 &gt;&gt; , maxlen : 32 } iex&gt; brot ( &quot;1.2.3.4&quot; , 8 ) &quot;4.1.2.3&quot; iex&gt; brot ( { 1 , 2 , 3 , 4 } , 8 ) { 4 , 1 , 2 , 3 } iex&gt; brot ( { { 1 , 2 , 3 , 4 } , 32 } , - 8 ) { { 2 , 3 , 4 , 1 } , 32 } # remember, its &lt;&lt;1, 2&gt;&gt; that gets rotated (!) iex&gt; brot ( { { 1 , 2 , 3 , 4 } , 16 } , 8 ) { { 2 , 1 , 0 , 0 } , 16 }","ref":"Pfx.html#brot/2","title":"Pfx.brot/2","type":"function"},{"doc":"Set all pfx.bits to either 0 or 1 . Examples iex&gt; bset ( % Pfx { bits : &lt;&lt; 1 , 1 , 1 &gt;&gt; , maxlen : 32 } ) % Pfx { bits : &lt;&lt; 0 , 0 , 0 &gt;&gt; , maxlen : 32 } iex&gt; bset ( % Pfx { bits : &lt;&lt; 1 , 1 , 1 &gt;&gt; , maxlen : 32 } , 1 ) % Pfx { bits : &lt;&lt; 255 , 255 , 255 &gt;&gt; , maxlen : 32 } # defaults to `0`-bit iex&gt; bset ( &quot;1.1.1.0/24&quot; ) &quot;0.0.0.0/24&quot; iex&gt; bset ( &quot;1.1.1.0/24&quot; , 1 ) &quot;255.255.255.0/24&quot; iex&gt; bset ( { { 1 , 1 , 1 , 0 } , 24 } , 1 ) { { 255 , 255 , 255 , 0 } , 24 }","ref":"Pfx.html#bset/2","title":"Pfx.bset/2","type":"function"},{"doc":"Arithmetic shift left the pfx.bits by n positions. A positive n shifts to the left, negative n shifts to the right. Note that the length of pfx.bits stays the same. Examples iex&gt; bsl ( % Pfx { bits : &lt;&lt; 1 , 2 &gt;&gt; , maxlen : 32 } , 2 ) % Pfx { bits : &lt;&lt; 4 , 8 &gt;&gt; , maxlen : 32 } iex&gt; bsl ( % Pfx { bits : &lt;&lt; 1 , 2 &gt;&gt; , maxlen : 32 } , - 2 ) % Pfx { bits : &lt;&lt; 0 , 64 &gt;&gt; , maxlen : 32 } # mask is applied when creating a `Pfx` out of &quot;1.2.3.4/16&quot; iex&gt; bsl ( &quot;1.2.3.4/16&quot; , 2 ) &quot;4.8.0.0/16&quot; iex&gt; bsl ( { 1 , 2 , 3 , 4 } , 2 ) { 4 , 8 , 12 , 16 } # remember, its &lt;&lt;1, 2&gt;&gt; that gets shifted left 2 bits iex&gt; bsl ( { { 1 , 2 , 3 , 4 } , 16 } , 2 ) { { 4 , 8 , 0 , 0 } , 16 }","ref":"Pfx.html#bsl/2","title":"Pfx.bsl/2","type":"function"},{"doc":"Arithmetic shift right the pfx.bits by n positions. A negative n actually shifts to the left. Note that the pfx.bits stays stays the same. Examples iex&gt; bsr ( % Pfx { bits : &lt;&lt; 1 , 2 &gt;&gt; , maxlen : 32 } , 2 ) % Pfx { bits : &lt;&lt; 0 , 64 &gt;&gt; , maxlen : 32 } # now shift to the left iex&gt; bsr ( % Pfx { bits : &lt;&lt; 1 , 2 &gt;&gt; , maxlen : 32 } , - 2 ) % Pfx { bits : &lt;&lt; 4 , 8 &gt;&gt; , maxlen : 32 } # mask get applied when creating a `Pfx` iex&gt; bsr ( &quot;1.2.3.4/16&quot; , 2 ) &quot;0.64.0.0/16&quot; # no mask, so all 32 bits get shifted iex&gt; bsr ( { 1 , 2 , 0 , 0 } , 2 ) { 0 , 64 , 128 , 0 } iex&gt; bsr ( { { 1 , 2 , 3 , 4 } , 16 } , 2 ) { { 0 , 64 , 0 , 0 } , 16 }","ref":"Pfx.html#bsr/2","title":"Pfx.bsr/2","type":"function"},{"doc":"A bitwise XOR of two t:prefix 's. Both prefixes must have the same maxlen . Examples iex&gt; x = new ( &lt;&lt; 10 , 11 , 12 , 13 &gt;&gt; , 32 ) iex&gt; y = new ( &lt;&lt; 255 , 255 &gt;&gt; , 32 ) iex&gt; bxor ( x , y ) % Pfx { bits : &lt;&lt; 245 , 244 , 12 , 13 &gt;&gt; , maxlen : 32 } iex&gt; bxor ( % Pfx { bits : &lt;&lt; 10 , 11 , 12 , 13 &gt;&gt; , maxlen : 32 } , &quot;255.255.0.0&quot; ) % Pfx { bits : &lt;&lt; 245 , 244 , 12 , 13 &gt;&gt; , maxlen : 32 } iex&gt; bxor ( &quot;10.11.12.13&quot; , { 255 , 255 , 0 , 0 } ) &quot;245.244.12.13&quot; iex&gt; bxor ( { 10 , 11 , 12 , 13 } , &quot;255.255.0.0&quot; ) { 245 , 244 , 12 , 13 } iex&gt; bxor ( { { 10 , 11 , 12 , 13 } , 32 } , &quot;255.255.0.0&quot; ) { { 245 , 244 , 12 , 13 } , 32 }","ref":"Pfx.html#bxor/2","title":"Pfx.bxor/2","type":"function"},{"doc":"Cast a prefix/0 to an integer. After right padding the given pfx , the pfx.bits are interpreted as a number of maxlen bits wide. Empty prefixes evaluate to 0 , since all 'missing' bits are taken to be zero (even if maxlen is 0 ). See cut/3 for how this capability might be useful. Examples iex&gt; cast ( % Pfx { bits : &lt;&lt; 255 , 255 &gt;&gt; , maxlen : 16 } ) 65535 # missing bits filled in as `0`s iex&gt; cast ( % Pfx { bits : &lt;&lt; 255 &gt;&gt; , maxlen : 16 } ) 65280 iex&gt; cast ( % Pfx { bits : &lt;&lt; - 1 :: 128 &gt;&gt; , maxlen : 128 } ) 340282366920938463463374607431768211455 iex&gt; cast ( % Pfx { bits : &lt;&lt; &gt;&gt; , maxlen : 8 } ) 0 # a bit weird, but: iex&gt; cast ( % Pfx { bits : &lt;&lt; &gt;&gt; , maxlen : 0 } ) 0 iex&gt; cast ( % Pfx { bits : &lt;&lt; 255 , 255 , 0 , 0 &gt;&gt; , maxlen : 32 } ) 4294901760 iex&gt; cast ( { 255 , 255 , 0 , 0 } ) 4294901760 iex&gt; cast ( { { 255 , 255 , 0 , 0 } , 32 } ) 4294901760 iex&gt; cast ( &quot;255.255.0.0&quot; ) 4294901760","ref":"Pfx.html#cast/1","title":"Pfx.cast/1","type":"function"},{"doc":"Compare function for sorting. :eq prefix1 is equal to prefix2 :lt prefix1 has more bits or lies to the left of prefix2 :gt prefix1 has less bits or lies to the right of prefix2 The prefixes must have the same maxlen and are first compared by size (i.e. a shorter prefix is considered larger ), and second on their bitstring value. Examples iex&gt; compare ( new ( &lt;&lt; 10 &gt;&gt; , 32 ) , new ( &lt;&lt; 11 &gt;&gt; , 32 ) ) :lt iex&gt; compare ( &quot;10.0.0.0/8&quot; , &quot;11.0.0.0/8&quot; ) :lt iex&gt; compare ( &quot;10.0.0.0/8&quot; , { { 11 , 0 , 0 , 0 } , 8 } ) :lt iex&gt; compare ( { 10 , 0 , 0 , 0 } , { { 11 , 0 , 0 , 0 } , 16 } ) :lt # sort on `pfx.bits` size first, than on `pfx.bits` values iex&gt; l = [ new ( &lt;&lt; 10 , 11 &gt;&gt; , 32 ) , new ( &lt;&lt; 10 , 10 , 10 &gt;&gt; , 32 ) , new ( &lt;&lt; 10 , 10 &gt;&gt; , 32 ) ] iex&gt; Enum . sort ( l , Pfx ) [ % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 11 &gt;&gt; , maxlen : 32 } ] # # whereas regular sort does: # iex&gt; Enum . sort ( l ) [ % Pfx { bits : &lt;&lt; 10 , 10 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 11 &gt;&gt; , maxlen : 32 } ] iex&gt; l = [ &quot;10.11.0.0/16&quot; , &quot;10.10.10.0/24&quot; , &quot;10.10.0.0/16&quot; ] iex&gt; Enum . sort ( l , Pfx ) [ &quot;10.10.10.0/24&quot; , &quot;10.10.0.0/16&quot; , &quot;10.11.0.0/16&quot; ] # not advisable, you mixed representations are possible as well iex&gt; l = [ &quot;10.11.0.0/16&quot; , { { 10 , 10 , 10 , 0 } , 24 } , % Pfx { bits : &lt;&lt; 10 , 10 &gt;&gt; , maxlen : 32 } ] iex&gt; Enum . sort ( l , Pfx ) [ { { 10 , 10 , 10 , 0 } , 24 } , % Pfx { bits : &lt;&lt; 10 , 10 &gt;&gt; , maxlen : 32 } , &quot;10.11.0.0/16&quot; , ] # note: all prefixes must have the same `maxlen` iex&gt; compare ( new ( &lt;&lt; 10 &gt;&gt; , 32 ) , new ( &lt;&lt; 10 &gt;&gt; , 128 ) ) ** (ArgumentError) prefixes have different maxlen&#39;s: {%Pfx{bits: &quot;\\n&quot;, maxlen: 32}, %Pfx{bits: &quot;\\n&quot;, maxlen: 128}}","ref":"Pfx.html#compare/2","title":"Pfx.compare/2","type":"function"},{"doc":"Contrast two Pfx prefixes Contrasting two prefixes will yield one of: :equal pfx1 is equal to pfx2 :more pfx1 is a more specific version of pfx2 :less pfx1 is a less specific version of pfx2 :left pfx1 is left-adjacent to pfx2 :right pfx1 is right-adjacent to pfx2 :disjoint pfx1 has no match with pfx2 whatsoever. Examples iex&gt; contrast ( &quot;10.10.0.0/16&quot; , &quot;10.10.0.0/16&quot; ) :equal iex&gt; contrast ( &quot;10.10.10.0/24&quot; , &quot;10.10.0.0/16&quot; ) :more iex&gt; contrast ( &quot;10.0.0.0/8&quot; , &quot;10.255.255.0/24&quot; ) :less iex&gt; contrast ( &quot;1.2.3.0/24&quot; , &quot;1.2.4.0/24&quot; ) :left iex&gt; contrast ( &quot;1.2.3.4/30&quot; , &quot;1.2.3.0/30&quot; ) :right iex&gt; contrast ( &quot;10.10.0.0/16&quot; , &quot;9.0.0.0/8&quot; ) :disjoint iex&gt; contrast ( &quot;10.10.0.0/16&quot; , % Pfx { bits : &lt;&lt; 10 , 12 &gt;&gt; , maxlen : 32 } ) :disjoint","ref":"Pfx.html#contrast/2","title":"Pfx.contrast/2","type":"function"},{"doc":"Cut out a series of bits and turn it into its own Pfx . This basically uses &amp;bits/3 to extract the bits and wraps it in a Pfx.t/0 with its maxlen set to the length of the bits extracted. Examples As per example on wikipedia for an IPv6 address 2001:0000:4136:e378:8000:63bf:3fff:fdd2 that refers to a Teredo client: iex&gt; teredo = new ( &lt;&lt; 0x2001 :: 16 , 0 :: 16 , 0x4136 :: 16 , 0xe378 :: 16 , ...&gt; 0x8000 :: 16 , 0x63bf :: 16 , 0x3fff :: 16 , 0xfdd2 :: 16 &gt;&gt; , 128 ) iex&gt; iex&gt; # client iex&gt; cut ( teredo , 96 , 32 ) |&gt; bnot ( ) |&gt; format ( ) &quot;192.0.2.45&quot; iex&gt; iex&gt; iex&gt; # udp port iex&gt; cut ( teredo , 80 , 16 ) |&gt; bnot ( ) |&gt; cast ( ) 40000 iex&gt; iex&gt; # teredo server iex&gt; cut ( teredo , 32 , 32 ) |&gt; format ( ) &quot;65.54.227.120&quot; iex&gt; iex&gt; # flags iex&gt; cut ( teredo , 64 , 16 ) |&gt; digits ( 1 ) |&gt; elem ( 0 ) { 1 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } &quot;Missing&quot; bits are considered to be zero. # extract 2nd and 3rd byte: iex&gt; % Pfx { bits : &lt;&lt; 255 , 255 &gt;&gt; , maxlen : 32 } |&gt; cut ( 8 , 16 ) % Pfx { bits : &lt;&lt; 255 , 0 &gt;&gt; , maxlen : 16 } Extraction must stay within maxlen of given pfx . # cannot exceed boundaries though: iex&gt; % Pfx { bits : &lt;&lt; 255 , 255 &gt;&gt; , maxlen : 32 } |&gt; cut ( 8 , 32 ) ** (ArgumentError) invalid index range: {8, 32}","ref":"Pfx.html#cut/3","title":"Pfx.cut/3","type":"function"},{"doc":"Transform a Pfx prefix into {digits, len} format. The pfx is padded to its maximum length using 0 's and the resulting bits are grouped into digits , each width -bits wide. The resulting len denotes the original pfx.bits bit_size. Note: works best if pfx.maxlen is a multiple of the width used, otherwise maxlen cannot be inferred from this format by tuple_size(digits) * width (e.g. by Pfx.undigits ) Examples iex&gt; digits ( % Pfx { bits : &lt;&lt; 10 , 11 , 12 &gt;&gt; , maxlen : 32 } , 8 ) { { 10 , 11 , 12 , 0 } , 24 } # not obvious that each number is 4 bits wide iex&gt; digits ( % Pfx { bits : &lt;&lt; 0x12 , 0x34 , 0x56 , 0x78 &gt;&gt; , maxlen : 128 } , 4 ) { { 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } , 32 } iex&gt; digits ( % Pfx { bits : &lt;&lt; 10 , 11 , 12 , 1 :: 1 &gt;&gt; , maxlen : 32 } , 8 ) { { 10 , 11 , 12 , 128 } , 25 } iex&gt; digits ( % Pfx { bits : &lt;&lt; 0xacdc :: 16 , 0x1976 :: 16 &gt;&gt; , maxlen : 128 } , 16 ) { { 44252 , 6518 , 0 , 0 , 0 , 0 , 0 , 0 } , 32 } iex&gt; digits ( &quot;acdc:1976::/32&quot; , 16 ) { { 44252 , 6518 , 0 , 0 , 0 , 0 , 0 , 0 } , 32 } iex&gt; digits ( { { 0xacdc , 0x1976 , 0 , 0 , 0 , 0 , 0 , 0 } , 32 } , 16 ) { { 44252 , 6518 , 0 , 0 , 0 , 0 , 0 , 0 } , 32 }","ref":"Pfx.html#digits/2","title":"Pfx.digits/2","type":"function"},{"doc":"Return a reverse DNS name (pointer) for given pfx . The prefix will be padded right with 0 -bits to a multiple of 8 for IPv4 prefixes and to a multiple of 4 for IPv6 prefixes. Note that this might give unexpected results. So dns_ptr/1 works best if the prefix given is actually a multiple of 4 or 8. Examples iex&gt; dns_ptr ( &quot;10.10.0.0/16&quot; ) &quot;10.10.in-addr.arpa&quot; # &quot;1.2.3.0/23&quot; actually encodes as %Pfx{bits: &lt;&lt;1, 2, 1::size(7)&gt;&gt;, maxlen: 32} # and padding right with 0-bits to a /24 yields the 1.2.2.0/24 ... iex&gt; dns_ptr ( &quot;1.2.3.0/23&quot; ) &quot;2.2.1.in-addr.arpa&quot; iex&gt; dns_ptr ( &quot;acdc:1976::/32&quot; ) &quot;6.7.9.1.c.d.c.a.ip6.arpa&quot; # https://www.youtube.com/watch?v=VD7BV-z5GsE iex&gt; dns_ptr ( &quot;acdc:1975::b1ba:2021&quot; ) &quot;1.2.0.2.a.b.1.b.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.5.7.9.1.c.d.c.a.ip6.arpa&quot;","ref":"Pfx.html#dns_ptr/1","title":"Pfx.dns_ptr/1","type":"function"},{"doc":"Turn a pfx.bits string into a list of {number, width} -fields. If bit_size(pfx.bits) is not a multiple of width , the last {number, width} -tuple, will have a smaller width. Examples iex&gt; fields ( % Pfx { bits : &lt;&lt; 10 , 11 , 12 , 13 &gt;&gt; , maxlen : 32 } , 8 ) [ { 10 , 8 } , { 11 , 8 } , { 12 , 8 } , { 13 , 8 } ] # not a multiple of 8 iex&gt; fields ( % Pfx { bits : &lt;&lt; 10 , 11 , 12 , 0 :: 1 &gt;&gt; , maxlen : 32 } , 8 ) [ { 10 , 8 } , { 11 , 8 } , { 12 , 8 } , { 0 , 1 } ] iex&gt; new ( &lt;&lt; 0xacdc :: 16 &gt;&gt; , 128 ) |&gt; fields ( 4 ) [ { 10 , 4 } , { 12 , 4 } , { 13 , 4 } , { 12 , 4 } ] iex&gt; fields ( &quot;10.11.12.13&quot; , 8 ) [ { 10 , 8 } , { 11 , 8 } , { 12 , 8 } , { 13 , 8 } ] iex&gt; fields ( { 10 , 11 , 12 , 13 } , 8 ) [ { 10 , 8 } , { 11 , 8 } , { 12 , 8 } , { 13 , 8 } ] iex&gt; fields ( { { 10 , 11 , 12 , 0 } , 24 } , 8 ) [ { 10 , 8 } , { 11 , 8 } , { 12 , 8 } ] # only 1 field with less bits than given width of 64 iex&gt; new ( &lt;&lt; 255 , 255 &gt;&gt; , 32 ) |&gt; fields ( 64 ) [ { 65535 , 16 } ]","ref":"Pfx.html#fields/2","title":"Pfx.fields/2","type":"function"},{"doc":"Generic formatter to turn a Pfx into a string, using several options: :width , field width (default 8) :base , howto turn a field into a string (default 10, use 16 for hex numbers) :unit , how many fields go into 1 section (default 1) :ssep , howto join the sections together (default &quot;.&quot;) :lsep , howto join a mask if required (default &quot;/&quot;) :mask , whether to add a mask (default false) :reverse , whether to reverse fields before grouping/joining (default false) :padding , whether to pad out the pfx.bits (default true) The defaults are geared towards IPv4 prefixes, but the options should be able to accomodate other domains as well. Notes: the prefix.bits -length is omitted if equal to the prefix.bits -size domain specific submodules probably implement their own formatter. Examples iex&gt; format ( % Pfx { bits : &lt;&lt; 10 , 11 , 12 &gt;&gt; , maxlen : 32 } ) &quot;10.11.12.0/24&quot; iex&gt; format ( { { 10 , 11 , 12 , 0 } , 24 } ) &quot;10.11.12.0/24&quot; iex&gt; format ( { 10 , 11 , 12 , 0 } ) &quot;10.11.12.0&quot; # non-sensical, but there you go iex&gt; format ( &quot;10.11.12.0/24&quot; ) &quot;10.11.12.0/24&quot; # bitstring, note that mask is applied when new creates the `pfx` iex&gt; format ( &quot;1.2.3.4/24&quot; , width : 1 , base : 2 , unit : 8 , mask : false ) &quot;00000001.00000010.00000011.00000000&quot; # mask not appended as its redundant for a full-sized prefix iex&gt; format ( % Pfx { bits : &lt;&lt; 10 , 11 , 12 , 13 &gt;&gt; , maxlen : 32 } ) &quot;10.11.12.13&quot; iex&gt; pfx = new ( &lt;&lt; 0xacdc :: 16 , 0x1976 :: 16 &gt;&gt; , 128 ) iex&gt; format ( pfx , width : 16 , base : 16 , ssep : &quot;:&quot; ) &quot;acdc:1976:0:0:0:0:0:0/32&quot; # # similar, but grouping 4 fields, each 4 bits wide, into a single section # iex&gt; format ( pfx , width : 4 , base : 16 , unit : 4 , ssep : &quot;:&quot; ) &quot;acdc:1976:0000:0000:0000:0000:0000:0000/32&quot; # # this time, omit the acutal pfx length # iex&gt; format ( pfx , width : 16 , base : 16 , ssep : &quot;:&quot; , mask : false ) &quot;acdc:1976:0:0:0:0:0:0&quot; # # ptr for IPv6 using the nibble format: # - dot-separated reversal of all hex digits in the expanded address # iex&gt; pfx ...&gt; |&gt; format ( width : 4 , base : 16 , mask : false , reverse : true ) ...&gt; |&gt; String . downcase ( ) ...&gt; |&gt; ( fn x -&gt; &quot; \#{ x } .ip6.arpa.&quot; end ) . ( ) &quot;0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.6.7.9.1.c.d.c.a.ip6.arpa.&quot; # turn off padding to get reverse zone dns ptr record iex&gt; new ( &lt;&lt; 10 , 11 , 12 &gt;&gt; , 32 ) ...&gt; |&gt; format ( padding : false , reverse : true , mask : false ) ...&gt; |&gt; ( &amp; &quot; \#{ &amp;1 } .in-addr.arpa.&quot; ) . ( ) &quot;12.11.10.in-addr.arpa.&quot;","ref":"Pfx.html#format/2","title":"Pfx.format/2","type":"function"},{"doc":"Return the nth host in given pfx . The result is in the same format as pfx . Note that offset nth wraps around. See Pfx.member/2 . Example iex&gt; host ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } , 128 ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 128 &gt;&gt; , maxlen : 32 } iex&gt; host ( { { 10 , 10 , 10 , 0 } , 24 } , 128 ) { { 10 , 10 , 10 , 128 } , 32 } iex&gt; host ( { 10 , 10 , 10 , 10 } , 13 ) { 10 , 10 , 10 , 10 } iex&gt; host ( &quot;10.10.10.0/24&quot; , 128 ) &quot;10.10.10.128&quot;","ref":"Pfx.html#host/2","title":"Pfx.host/2","type":"function"},{"doc":"Returns a list of address prefixes for given pfx . The result is in the same format as pfx . Examples iex&gt; hosts ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 0 :: 6 &gt;&gt; , maxlen : 32 } ) [ % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 0 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 1 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 2 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 3 &gt;&gt; , maxlen : 32 } ] iex&gt; hosts ( &quot;10.10.10.0/30&quot; ) [ &quot;10.10.10.0&quot; , &quot;10.10.10.1&quot; , &quot;10.10.10.2&quot; , &quot;10.10.10.3&quot; ] iex&gt; hosts ( { { 10 , 10 , 10 , 0 } , 30 } ) [ { { 10 , 10 , 10 , 0 } , 32 } , { { 10 , 10 , 10 , 1 } , 32 } , { { 10 , 10 , 10 , 2 } , 32 } , { { 10 , 10 , 10 , 3 } , 32 } ]","ref":"Pfx.html#hosts/1","title":"Pfx.hosts/1","type":"function"},{"doc":"Returns the inverted mask for given pfx . The result is in the same format as pfx . Examples iex&gt; inv_mask ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 0 :: 1 &gt;&gt; , maxlen : 32 } ) % Pfx { bits : &lt;&lt; 0 , 0 , 0 , 127 &gt;&gt; , maxlen : 32 } iex&gt; inv_mask ( { { 10 , 10 , 10 , 0 } , 25 } ) { { 0 , 0 , 0 , 127 } , 32 } iex&gt; inv_mask ( { 10 , 10 , 10 , 0 } ) { 0 , 0 , 0 , 0 } iex&gt; inv_mask ( &quot;10.10.10.0/25&quot; ) &quot;0.0.0.127&quot;","ref":"Pfx.html#inv_mask/1","title":"Pfx.inv_mask/1","type":"function"},{"doc":"Guard that ensures both prefixes are valid and comparable (same maxlen).","ref":"Pfx.html#is_comparable/2","title":"Pfx.is_comparable/2","type":"macro"},{"doc":"Guard that ensures a given pfx is actually valid. it is a Pfx.t/0 struct, pfx.maxlen is a t:non-neg-integer/0 , pfx.maxlen is &gt;= 0, and bit_size(pfx.bits) &lt;= pfx.maxlen","ref":"Pfx.html#is_pfx/1","title":"Pfx.is_pfx/1","type":"macro"},{"doc":"Return a map with link-local address components for given pfx . Returns nil if pfx is not link-local as per rfc3927 Examples iex&gt; x = link_local ( &quot;169.254.128.233&quot; ) iex&gt; x %{ digits : { 169 , 254 , 128 , 233 } , prefix : &quot;169.254.0.0/16&quot; , ifaceID : 33001 , address : &quot;169.254.128.233&quot; } # iex&gt; host ( x . prefix , x . ifaceID ) &quot;169.254.128.233&quot; iex&gt; y = link_local ( &quot;fe80::acdc:1976&quot; ) iex&gt; y %{ preamble : 1018 , prefix : &quot;fe80:0:0:0:0:0:0:0/64&quot; , ifaceID : 2900105590 , address : &quot;fe80:0:0:0:0:0:acdc:1976&quot; } # iex&gt; host ( y . prefix , y . ifaceID ) &quot;fe80:0:0:0:0:0:acdc:1976&quot;","ref":"Pfx.html#link_local/1","title":"Pfx.link_local/1","type":"function"},{"doc":"Returns true if pfx is a link-local prefix, false otherwise Link local prefixes include: 0.0.0.0/8 , rfc1122 , 'this-network' 255.255.255.255/32 , rfc1f22 , limited broadcast 169.254.0.0/16 , rfc3927 , link-local (see examples) fe80::/64 , rfc4291 , link-local Examples # first 256 addresses are reserved iex&gt; link_local? ( &quot;169.254.0.0&quot; ) false # last 256 addresses are reserved iex&gt; link_local? ( &quot;169.254.255.0&quot; ) false # rest is considered link local iex&gt; link_local? ( &quot;169.254.1.0&quot; ) true iex&gt; link_local? ( &quot;169.254.254.255&quot; ) true iex&gt; link_local? ( &quot;0.0.0.0&quot; ) true iex&gt; link_local? ( &quot;0.255.255.255&quot; ) true iex&gt; link_local? ( { 0 , 255 , 255 , 255 } ) true iex&gt; link_local? ( &quot;fe80::acdc:1975&quot; ) true iex&gt; link_local? ( &quot;1.1.1.1&quot; ) false # bad prefix iex&gt; link_local? ( &quot;10.10.10.256&quot; ) false","ref":"Pfx.html#link_local?/1","title":"Pfx.link_local?/1","type":"function"},{"doc":"Return the mask as a Pfx for given pfx . The result is in the same format as pfx . Examples iex&gt; mask ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 1 :: 1 &gt;&gt; , maxlen : 32 } ) % Pfx { bits : &lt;&lt; 255 , 255 , 255 , 128 &gt;&gt; , maxlen : 32 } iex&gt; mask ( { { 10 , 10 , 10 , 1 } , 25 } ) { { 255 , 255 , 255 , 128 } , 32 } iex&gt; mask ( { 10 , 10 , 10 , 1 } ) { 255 , 255 , 255 , 255 } iex&gt; mask ( &quot;10.10.10.128/25&quot; ) &quot;255.255.255.128&quot;","ref":"Pfx.html#mask/1","title":"Pfx.mask/1","type":"function"},{"doc":"Return the nth -member of a given pfx . A prefix represents a range of (possibly longer) prefixes which can be seen as members of the prefix. So a prefix of n -bits long represents: 1 prefix of n -bits long (i.e. itself), 2 prefixes of n+1 -bits long, 4 prefixes of n+2 -bits long .. 2^w prefixes of n+w -bits long where n+w &lt;= pfx.maxlen . Not specifying a width assumes the maximum width available. If a width is specified, the nth -offset is added to the prefix as a number width -bits wide. This wraps around since &lt;&lt;16::4&gt;&gt; comes out as &lt;&lt;0::4&gt;&gt; . Examples iex&gt; member ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } , 0 ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 0 &gt;&gt; , maxlen : 32 } iex&gt; member ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } , 255 ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 255 &gt;&gt; , maxlen : 32 } # wraps around iex&gt; member ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } , 256 ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 0 &gt;&gt; , maxlen : 32 } iex&gt; member ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } , - 1 ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 255 &gt;&gt; , maxlen : 32 } # a full prefix always returns itself iex&gt; member ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 10 &gt;&gt; , maxlen : 32 } , 0 ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 10 &gt;&gt; , maxlen : 32 } iex&gt; member ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 10 &gt;&gt; , maxlen : 32 } , 3 ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 10 &gt;&gt; , maxlen : 32 } # other representations work too iex&gt; member ( &quot;10.10.10.0/24&quot; , 255 ) &quot;10.10.10.255&quot; iex&gt; member ( &quot;10.10.10.0/24&quot; , 256 ) &quot;10.10.10.0&quot; iex&gt; member ( { { 10 , 10 , 10 , 0 } , 24 } , 255 ) { { 10 , 10 , 10 , 255 } , 32 }","ref":"Pfx.html#member/2","title":"Pfx.member/2","type":"function"},{"doc":"Return the nth subprefix for a given pfx , using width bits. Examples # the first sub-prefix that is 2 bits longer iex&gt; member ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } , 0 , 2 ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 0 :: 2 &gt;&gt; , maxlen : 32 } # the second sub-prefix that is 2 bits longer iex&gt; member ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } , 1 , 2 ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 1 :: 2 &gt;&gt; , maxlen : 32 } iex&gt; member ( &quot;10.10.10.0/24&quot; , 1 , 2 ) &quot;10.10.10.64/26&quot; iex&gt; member ( &quot;10.10.10.0/24&quot; , 2 , 2 ) &quot;10.10.10.128/26&quot; iex&gt; member ( { { 10 , 10 , 10 , 0 } , 24 } , 2 , 2 ) { { 10 , 10 , 10 , 128 } , 26 }","ref":"Pfx.html#member/3","title":"Pfx.member/3","type":"function"},{"doc":"Returns true is prefix pfx1 is a member of prefix pfx2 If either prfx1 or pfx2 is invalid, member? simply returns false Examples iex&gt; member? ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 10 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 &gt;&gt; , maxlen : 32 } ) true iex&gt; member? ( &quot;10.10.10.10&quot; , &quot;10.0.0.0/8&quot; ) true iex&gt; member? ( { 10 , 10 , 10 , 10 } , &quot;10.0.0.0/8&quot; ) true iex&gt; member? ( { { 10 , 10 , 10 , 10 } , 24 } , &quot;10.0.0.0/8&quot; ) true iex&gt; member? ( { { 11 , 0 , 0 , 0 } , 8 } , { { 10 , 0 , 0 , 0 } , 8 } ) false # bad prefix iex&gt; member? ( &quot;10.10.10.10&quot; , &quot;10.10.10.256/24&quot; ) false","ref":"Pfx.html#member?/2","title":"Pfx.member?/2","type":"function"},{"doc":"Returns a map with multicast address components for given pfx . Returns nil if pfx is not a multicast address. Examples iex&gt; multicast ( &quot;ff02::1&quot; ) %{ preamble : 255 , flags : { 0 , 0 , 0 , 0 } , scope : 2 , groupID : &lt;&lt; 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 1 &gt;&gt; , address : &quot;ff02::1&quot; } iex&gt; multicast ( &quot;224.0.0.1&quot; ) %{ address : &quot;224.0.0.1&quot; , digits : { 224 , 0 , 0 , 1 } , groupID : &lt;&lt; 0 , 0 , 0 , 1 :: size ( 4 ) &gt;&gt; }","ref":"Pfx.html#multicast/1","title":"Pfx.multicast/1","type":"function"},{"doc":"Returns true is pfx is a multicast prefix, false otherwise Examples iex&gt; multicast? ( % Pfx { bits : &lt;&lt; 224 , 0 , 0 , 1 &gt;&gt; , maxlen : 32 } ) true iex&gt; multicast? ( { { 224 , 0 , 0 , 1 } , 32 } ) true iex&gt; multicast? ( { 224 , 0 , 0 , 1 } ) true iex&gt; multicast? ( &quot;224.0.0.1&quot; ) true iex&gt; multicast? ( &quot;ff02::1&quot; ) true iex&gt; multicast? ( &quot;1.1.1.1&quot; ) false # bad prefix iex&gt; multicast? ( &quot;224.0.0.256&quot; ) false","ref":"Pfx.html#multicast?/1","title":"Pfx.multicast?/1","type":"function"},{"doc":"Returns true if pfx is matched by the Well-Known Prefixes defined in rfc6053 and rfc8215 , false otherwise. Note that organisation specific prefixes might still be used for nat64. Example iex&gt; nat64? ( % Pfx { bits : &lt;&lt; 0x64 :: 16 , 0xff9b :: 16 , 0 :: 64 , 0x1010 :: 16 , 0x1010 :: 16 &gt;&gt; , maxlen : 128 } ) true iex&gt; nat64? ( { { 0x64 , 0xff9b , 0 , 0 , 0 , 0 , 0x1010 , 0x1010 } , 128 } ) true iex&gt; nat64? ( { 0x64 , 0xff9b , 0 , 0 , 0 , 0 , 0x1010 , 0x1010 } ) true iex&gt; nat64? ( &quot;64:ff9b::10.10.10.10&quot; ) true iex&gt; nat64? ( &quot;64:ff9b:1::10.10.10.10&quot; ) true # bad prefix iex&gt; nat64? ( &quot;64:ff9b:1::10.10.10.256&quot; ) false","ref":"Pfx.html#nat64?/1","title":"Pfx.nat64?/1","type":"function"},{"doc":"Returns the embedded IPv4 address of a nat64 pfx The pfx prefix should be a full IPv6 address. The len defaults to 96 , but if specified it should be one of [96, 64, 56, 48, 40, 32]. Examples iex&gt; nat64_decode ( &quot;64:ff9b::10.10.10.10&quot; ) &quot;10.10.10.10&quot; iex&gt; nat64_decode ( &quot;64:ff9b:1:0a0a:000a:0a00::&quot; , 48 ) &quot;10.10.10.10&quot; # from rfc6052, section 2.4 iex&gt; nat64_decode ( &quot;2001:db8:c000:221::&quot; , 32 ) &quot;192.0.2.33&quot; iex&gt; nat64_decode ( &quot;2001:db8:1c0:2:21::&quot; , 40 ) &quot;192.0.2.33&quot; iex&gt; nat64_decode ( &quot;2001:db8:122:c000:2:2100::&quot; , 48 ) &quot;192.0.2.33&quot; iex&gt; nat64_decode ( &quot;2001:db8:122:3c0:0:221::&quot; , 56 ) &quot;192.0.2.33&quot; iex&gt; nat64_decode ( &quot;2001:db8:122:344:c0:2:2100::&quot; , 64 ) &quot;192.0.2.33&quot; iex&gt; nat64_decode ( &quot;2001:db8:122:344::192.0.2.33&quot; , 96 ) &quot;192.0.2.33&quot; iex&gt; nat64_decode ( &quot;2001:db8:122:344::192.0.2.33&quot; , 90 ) ** (ArgumentError) error nat64_decode, &quot;len 90 not in: 96, 64, 56, 48, 40, 32&quot;","ref":"Pfx.html#nat64_decode/2","title":"Pfx.nat64_decode/2","type":"function"},{"doc":"Return an IPv4 embedded IPv6 address for given pfx6 and pfx4 . The length of the pfx6.bits should be one of [96, 64, 56, 48, 40, 32] as defined in rfc6052 . The pfx4 prefix should be a full address. Examples # from rfc6052, section 2.2 iex&gt; nat64_encode ( % Pfx { bits : &lt;&lt; 0x2001 :: 16 , 0xdb8 :: 16 &gt;&gt; , maxlen : 128 } , &quot;192.0.2.33&quot; ) % Pfx { bits : &lt;&lt; 0x2001 :: 16 , 0xdb8 :: 16 , 0xc000 :: 16 , 0x221 :: 16 , 0 :: 64 &gt;&gt; , maxlen : 128 } iex&gt; nat64_encode ( &quot;2001:db8::/32&quot; , &quot;192.0.2.33&quot; ) &quot;2001:db8:c000:221:0:0:0:0&quot; iex&gt; nat64_encode ( { { 0x2001 , 0xdb8 , 0 , 0 , 0 , 0 , 0 , 0 } , 32 } , &quot;192.0.2.33&quot; ) { { 0x2001 , 0xdb8 , 0xc000 , 0x221 , 0 , 0 , 0 , 0 } , 128 } # other examples iex&gt; nat64_encode ( &quot;2001:db8:100::/40&quot; , &quot;192.0.2.33&quot; ) &quot;2001:db8:1c0:2:21:0:0:0&quot; iex&gt; nat64_encode ( &quot;2001:db8:122::/48&quot; , &quot;192.0.2.33&quot; ) &quot;2001:db8:122:c000:2:2100:0:0&quot; iex&gt; nat64_encode ( &quot;2001:db8:122:300::/56&quot; , &quot;192.0.2.33&quot; ) &quot;2001:db8:122:3c0:0:221:0:0&quot; iex&gt; nat64_encode ( &quot;2001:db8:122:344::/64&quot; , &quot;192.0.2.33&quot; ) &quot;2001:db8:122:344:c0:2:2100:0&quot; iex&gt; nat64_encode ( &quot;2001:db8:122:344::/96&quot; , &quot;192.0.2.33&quot; ) &quot;2001:db8:122:344:0:0:c000:221&quot;","ref":"Pfx.html#nat64_encode/2","title":"Pfx.nat64_encode/2","type":"function"},{"doc":"Returns the neighboring prefix such that both can be combined in a supernet. The result is in the same format as pfx . Example iex&gt; neighbor ( % Pfx { bits : &lt;&lt; 1 , 1 , 1 , 1 :: 1 &gt;&gt; , maxlen : 32 } ) % Pfx { bits : &lt;&lt; 1 , 1 , 1 , 0 :: 1 &gt;&gt; , maxlen : 32 } iex&gt; neighbor ( { { 1 , 1 , 1 , 128 } , 25 } ) { { 1 , 1 , 1 , 0 } , 25 } iex&gt; neighbor ( { 1 , 1 , 1 , 1 } ) { 1 , 1 , 1 , 0 } iex&gt; neighbor ( &quot;1.1.1.0/25&quot; ) &quot;1.1.1.128/25&quot; iex&gt; neighbor ( &quot;1.1.1.128/25&quot; ) &quot;1.1.1.0/25&quot;","ref":"Pfx.html#neighbor/1","title":"Pfx.neighbor/1","type":"function"},{"doc":"Returns the this-network prefix (full address) for given pfx . The result is in the same format as pfx . Examples iex&gt; network ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 0 &gt;&gt; , maxlen : 32 } # mask is applied to address iex&gt; network ( { { 10 , 10 , 10 , 1 } , 24 } ) { { 10 , 10 , 10 , 0 } , 32 } # a full address is its own this-network iex&gt; network ( { 10 , 10 , 10 , 1 } ) { 10 , 10 , 10 , 1 } iex&gt; network ( &quot;10.10.10.1/24&quot; ) &quot;10.10.10.0&quot; iex&gt; network ( % Pfx { bits : &lt;&lt; 0xacdc :: 16 , 0x1976 :: 16 &gt;&gt; , maxlen : 128 } ) % Pfx { bits : &lt;&lt; 0xACDC :: 16 , 0x1976 :: 16 , 0 :: 96 &gt;&gt; , maxlen : 128 } iex&gt; network ( &quot;acdc:1976::/32&quot; ) &quot;acdc:1976:0:0:0:0:0:0&quot;","ref":"Pfx.html#network/1","title":"Pfx.network/1","type":"function"},{"doc":"Creates a new prefix from address tuples or binaries. Use: an ipv4 or ipv6 ip_address/0 tuple directly for a full address, or a { ip_address/0 , length }-tuple to truncate the bits to length . a binary in CIDR -notation, like &quot;acdc:1976::/32&quot; Binaries are processed by :inet.parse_address/1 , so be aware of IPv4 shorthand notations that may yield surprising results, since digits are taken to be: d1.d2.d3.d4 -&gt; d1.d2.d3.d4 (full address) d1.d2.d3 -&gt; d1.d2.0.d3 d1.d2 -&gt; d1.0.0.d2 d1 -&gt; 0.0.0.d1 Examples iex&gt; new ( { { 0xacdc , 0x1976 , 0 , 0 , 0 , 0 , 0 , 0 } , 32 } ) % Pfx { bits : &lt;&lt; 0xacdc :: 16 , 0x1976 :: 16 &gt;&gt; , maxlen : 128 } iex&gt; new ( { 10 , 10 , 0 , 0 } ) % Pfx { bits : &lt;&lt; 10 , 10 , 0 , 0 &gt;&gt; , maxlen : 32 } iex&gt; new ( { { 10 , 10 , 0 , 0 } , 16 } ) % Pfx { bits : &lt;&lt; 10 , 10 &gt;&gt; , maxlen : 32 } iex&gt; new ( &quot;10.10.0.0&quot; ) % Pfx { bits : &lt;&lt; 10 , 10 , 0 , 0 &gt;&gt; , maxlen : 32 } iex&gt; new ( &quot;10.10.10.10/16&quot; ) % Pfx { bits : &lt;&lt; 10 , 10 &gt;&gt; , maxlen : 32 } # 10.10/16 is interpreted as 10.0.0.10/16 (!) iex&gt; new ( &quot;10.10/16&quot; ) % Pfx { bits : &lt;&lt; 10 , 0 &gt;&gt; , maxlen : 32 }","ref":"Pfx.html#new/1","title":"Pfx.new/1","type":"function"},{"doc":"Creates a new Pfx.t/0 -prefix. A prefix can be created from: from a bitstring and a maximum length, truncating the bits as needed, from a Pfx.t/0 prefix and a new maxlen, again truncating as needed, from an ipv4 or ipv6 ip_address/0 tuple from an { ip_address/0 , length } tuple The last form sets the maxlen according to the IP protocol version used, while the length parameter is used to truncate the bits for the prefix. Examples iex&gt; new ( &lt;&lt; 10 , 10 &gt;&gt; , 32 ) % Pfx { bits : &lt;&lt; 10 , 10 &gt;&gt; , maxlen : 32 } iex&gt; new ( &lt;&lt; 10 , 10 &gt;&gt; , 8 ) % Pfx { bits : &lt;&lt; 10 &gt;&gt; , maxlen : 8 } # Create a new `Pfx` from an existing one, note: # this changes the `Pfx`&#39;s meaning iex&gt; new ( &lt;&lt; 10 , 10 &gt;&gt; , 32 ) |&gt; new ( 128 ) % Pfx { bits : &lt;&lt; 10 , 10 &gt;&gt; , maxlen : 128 }","ref":"Pfx.html#new/2","title":"Pfx.new/2","type":"function"},{"doc":"Left pad the pfx.bits to its full length using 0 -bits. Example iex&gt; padl ( % Pfx { bits : &lt;&lt; 1 , 2 &gt;&gt; , maxlen : 32 } ) % Pfx { bits : &lt;&lt; 0 , 0 , 1 , 2 &gt;&gt; , maxlen : 32 } iex&gt; padl ( &quot;1.2.0.0/16&quot; ) &quot;0.0.1.2&quot; iex&gt; padl ( { { 1 , 2 , 0 , 0 } , 16 } ) { { 0 , 0 , 1 , 2 } , 32 }","ref":"Pfx.html#padl/1","title":"Pfx.padl/1","type":"function"},{"doc":"Left pad the pfx.bits to its full length using either 0 or 1 -bits. Example iex&gt; padl ( % Pfx { bits : &lt;&lt; 1 , 2 &gt;&gt; , maxlen : 32 } , 1 ) % Pfx { bits : &lt;&lt; 255 , 255 , 1 , 2 &gt;&gt; , maxlen : 32 } iex&gt; padl ( &quot;1.2.0.0/16&quot; , 1 ) &quot;255.255.1.2&quot; iex&gt; padl ( { { 1 , 2 , 0 , 0 } , 16 } , 1 ) { { 255 , 255 , 1 , 2 } , 32 }","ref":"Pfx.html#padl/2","title":"Pfx.padl/2","type":"function"},{"doc":"Left pad the pfx.bits with n bits of either 0 or 1 's. Example iex&gt; padl ( % Pfx { bits : &lt;&lt; 255 , 255 &gt;&gt; , maxlen : 32 } , 0 , 16 ) % Pfx { bits : &lt;&lt; 0 , 0 , 255 , 255 &gt;&gt; , maxlen : 32 } iex&gt; padl ( &quot;255.255.0.0/16&quot; , 0 , 16 ) &quot;0.0.255.255&quot; iex&gt; padl ( { { 255 , 255 , 0 , 0 } , 16 } , 0 , 16 ) { { 0 , 0 , 255 , 255 } , 32 }","ref":"Pfx.html#padl/3","title":"Pfx.padl/3","type":"function"},{"doc":"Right pad the pfx.bits to its full length using 0 -bits. The result is always a full prefix with maxlen bits. Example iex&gt; padr ( % Pfx { bits : &lt;&lt; 1 , 2 &gt;&gt; , maxlen : 32 } ) % Pfx { bits : &lt;&lt; 1 , 2 , 0 , 0 &gt;&gt; , maxlen : 32 } # already a full address iex&gt; padr ( &quot;1.2.0.0&quot; ) &quot;1.2.0.0&quot; # mask applied first, then padded with zero&#39;s iex&gt; padr ( &quot;1.2.3.4/16&quot; ) &quot;1.2.0.0&quot; # mask applied first, than padded with zero&#39;s iex&gt; padr ( { { 1 , 2 , 3 , 4 } , 16 } ) { { 1 , 2 , 0 , 0 } , 32 }","ref":"Pfx.html#padr/1","title":"Pfx.padr/1","type":"function"},{"doc":"Right pad the pfx.bits to its full length using either 0 or 1 -bits. Example iex&gt; padr ( % Pfx { bits : &lt;&lt; 1 , 2 &gt;&gt; , maxlen : 32 } , 1 ) % Pfx { bits : &lt;&lt; 1 , 2 , 255 , 255 &gt;&gt; , maxlen : 32 } iex&gt; padr ( &quot;1.2.0.0/16&quot; , 1 ) &quot;1.2.255.255&quot; iex&gt; padr ( { { 1 , 2 , 0 , 0 } , 16 } , 1 ) { { 1 , 2 , 255 , 255 } , 32 } # nothing to padr already a full prefix iex&gt; padr ( &quot;1.2.0.0&quot; , 1 ) &quot;1.2.0.0&quot; iex&gt; padr ( { 1 , 2 , 0 , 0 } , 1 ) { 1 , 2 , 0 , 0 }","ref":"Pfx.html#padr/2","title":"Pfx.padr/2","type":"function"},{"doc":"Right pad the pfx.bits with n bits of either 0 or 1 's. The result is clipped at maxlen bits without warning. Examples iex&gt; padr ( % Pfx { bits : &lt;&lt; 255 , 255 &gt;&gt; , maxlen : 32 } , 0 , 8 ) % Pfx { bits : &lt;&lt; 255 , 255 , 0 &gt;&gt; , maxlen : 32 } iex&gt; padr ( % Pfx { bits : &lt;&lt; 255 , 255 &gt;&gt; , maxlen : 32 } , 1 , 8 ) % Pfx { bits : &lt;&lt; 255 , 255 , 255 &gt;&gt; , maxlen : 32 } # results are clipped to maxlen iex&gt; new ( &lt;&lt; 1 , 2 &gt;&gt; , 32 ) |&gt; padr ( 0 , 512 ) % Pfx { bits : &lt;&lt; 1 , 2 , 0 , 0 &gt;&gt; , maxlen : 32 } iex&gt; padr ( &quot;255.255.0.0/16&quot; , 1 , 8 ) &quot;255.255.255.0/24&quot; iex&gt; padr ( { { 255 , 255 , 0 , 0 } , 16 } , 1 , 8 ) { { 255 , 255 , 255 , 0 } , 24 }","ref":"Pfx.html#padr/3","title":"Pfx.padr/3","type":"function"},{"doc":"Partition a Pfx prefix into a list of new prefixes, each bitlen long. Note that bitlen must be in the range of bit_size(pfx.bits)..pfx.maxlen-1 . Examples # break out the /26&#39;s in a /24 iex&gt; partition ( % Pfx { bits : &lt;&lt; 10 , 11 , 12 &gt;&gt; , maxlen : 32 } , 26 ) [ % Pfx { bits : &lt;&lt; 10 , 11 , 12 , 0 :: size ( 2 ) &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 11 , 12 , 1 :: size ( 2 ) &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 11 , 12 , 2 :: size ( 2 ) &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 11 , 12 , 3 :: size ( 2 ) &gt;&gt; , maxlen : 32 } ] iex&gt; partition ( &quot;10.11.12.0/24&quot; , 26 ) [ &quot;10.11.12.0/26&quot; , &quot;10.11.12.64/26&quot; , &quot;10.11.12.128/26&quot; , &quot;10.11.12.192/26&quot; ] iex&gt; partition ( { { 10 , 11 , 12 , 0 } , 24 } , 26 ) [ { { 10 , 11 , 12 , 0 } , 26 } , { { 10 , 11 , 12 , 64 } , 26 } , { { 10 , 11 , 12 , 128 } , 26 } , { { 10 , 11 , 12 , 192 } , 26 } , ]","ref":"Pfx.html#partition/2","title":"Pfx.partition/2","type":"function"},{"doc":"Returns another Pfx at distance offset . This basically increases or decreases the number represented by the pfx.bits while keeping pfx.maxlen the same. Note that the length of pfx.bits will not change and cycling through all siblings will eventually wrap around. Examples # next in line iex&gt; sibling ( % Pfx { bits : &lt;&lt; 10 , 11 &gt;&gt; , maxlen : 32 } , 1 ) % Pfx { bits : &lt;&lt; 10 , 12 &gt;&gt; , maxlen : 32 } # the last shall be the first iex&gt; sibling ( % Pfx { bits : &lt;&lt; 10 , 11 , 0 &gt;&gt; , maxlen : 32 } , 255 ) % Pfx { bits : &lt;&lt; 10 , 11 , 255 &gt;&gt; , maxlen : 32 } iex&gt; sibling ( % Pfx { bits : &lt;&lt; 10 , 11 , 0 &gt;&gt; , maxlen : 32 } , 256 ) % Pfx { bits : &lt;&lt; 10 , 12 , 0 &gt;&gt; , maxlen : 32 } # from one end to another iex&gt; new ( &lt;&lt; 0 , 0 , 0 , 0 &gt;&gt; , 32 ) |&gt; sibling ( - 1 ) % Pfx { bits : &lt;&lt; 255 , 255 , 255 , 255 &gt;&gt; , maxlen : 32 } # zero bit-length stays zero bit-length iex&gt; sibling ( % Pfx { bits : &lt;&lt; &gt;&gt; , maxlen : 0 } , 1 ) % Pfx { bits : &lt;&lt; &gt;&gt; , maxlen : 0 } iex&gt; sibling ( &quot;0.0.0.0&quot; , - 1 ) &quot;255.255.255.255&quot; iex&gt; sibling ( &quot;1.2.3.0/24&quot; , - 1 ) &quot;1.2.2.0/24&quot; iex&gt; sibling ( { { 1 , 2 , 3 , 0 } , 24 } , 256 ) { { 1 , 3 , 3 , 0 } , 24 }","ref":"Pfx.html#sibling/2","title":"Pfx.sibling/2","type":"function"},{"doc":"Returns the number of full addresses represented by given pfx . size(pfx) == 2^(pfx.maxlen - bit_size(pfx.bits)) Examples iex&gt; size ( % Pfx { bits : &lt;&lt; 1 , 1 , 1 &gt;&gt; , maxlen : 32 } ) 256 iex&gt; size ( { { 1 , 1 , 1 , 0 } , 16 } ) 65536 iex&gt; size ( { 1 , 1 , 1 , 1 } ) 1 iex&gt; size ( &quot;1.1.1.0/23&quot; ) 512","ref":"Pfx.html#size/1","title":"Pfx.size/1","type":"function"},{"doc":"Returns a map with the teredo address components of pfx or nil. Returns nil if pfx is not a teredo address. Examples # example from https://en.wikipedia.org/wiki/Teredo_tunneling#IPv6_addressing iex&gt; teredo ( &quot;2001:0000:4136:e378:8000:63bf:3fff:fdd2&quot; ) %{ server : &quot;65.54.227.120&quot; , client : &quot;192.0.2.45&quot; , port : 40000 , flags : { 1 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } , prefix : &quot;2001:0000:4136:e378:8000:63bf:3fff:fdd2&quot; } iex&gt; teredo ( { 0x2001 , 0 , 0x4136 , 0xe378 , 0x8000 , 0x63bf , 0x3fff , 0xfdd2 } ) %{ server : &quot;65.54.227.120&quot; , client : &quot;192.0.2.45&quot; , port : 40000 , flags : { 1 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } , prefix : { 0x2001 , 0x0 , 0x4136 , 0xe378 , 0x8000 , 0x63bf , 0x3fff , 0xfdd2 } } iex&gt; teredo ( &quot;1.1.1.1&quot; ) nil","ref":"Pfx.html#teredo/1","title":"Pfx.teredo/1","type":"function"},{"doc":"Returns true if prefix is a teredo address, false otherwise See rfc4380 . Example iex&gt; teredo? ( &quot;2001:0000:4136:e378:8000:63bf:3fff:fdd2&quot; ) true iex&gt; teredo? ( &quot;1.1.1.1&quot; ) false iex&gt; teredo? ( 42 ) false","ref":"Pfx.html#teredo?/1","title":"Pfx.teredo?/1","type":"function"},{"doc":"Return the Pfx prefix represented by the digits , actual length and a given field width . The pfx.bits are formed by first concatenating the digits expressed as bitstrings of width -bits wide and then truncating to the length -msb bits. The pfx.maxlen is inferred as tuple_size(digits) * width . Note: if a digit does not fit in width -bits, only the width -least significant bits are preserved, which may yield surprising results. Examples # truncated to the first 24 bits and maxlen is 32 (4*8) iex&gt; undigits ( { { 10 , 11 , 12 , 0 } , 24 } , 8 ) % Pfx { bits : &lt;&lt; 10 , 11 , 12 &gt;&gt; , maxlen : 32 } iex&gt; undigits ( { { - 1 , - 1 , 0 , 0 } , 32 } , 8 ) |&gt; format ( ) &quot;255.255.0.0&quot; # bits are truncated to empty bitstring (`length` is 0) iex&gt; undigits ( { { 1 , 2 , 3 , 4 } , 0 } , 8 ) % Pfx { bits : &lt;&lt; &gt;&gt; , maxlen : 32 }","ref":"Pfx.html#undigits/2","title":"Pfx.undigits/2","type":"function"},{"doc":"Returns true if pfx is designated as &quot;private-use&quot;. For IPv4 this includes the rfc1918 prefixes 10.0.0.0/8, 172.16.0.0/12 and 192.168.0.0/16. For IPv6 this includes the rfc4193 prefix fc00::/7. Examples iex&gt; unique_local? ( % Pfx { bits : &lt;&lt; 172 , 31 , 255 , 255 &gt;&gt; , maxlen : 32 } ) true iex&gt; unique_local? ( { { 172 , 31 , 255 , 255 } , 32 } ) true iex&gt; unique_local? ( { 172 , 31 , 255 , 255 } ) true iex&gt; unique_local? ( &quot;172.31.255.255&quot; ) true iex&gt; unique_local? ( &quot;10.10.10.10&quot; ) true iex&gt; unique_local? ( &quot;fc00:acdc::&quot; ) true iex&gt; unique_local? ( &quot;172.32.0.0&quot; ) false iex&gt; unique_local? ( &quot;10.255.255.255&quot; ) true # bad prefix iex&gt; unique_local? ( &quot;10.255.255.256&quot; ) false","ref":"Pfx.html#unique_local?/1","title":"Pfx.unique_local?/1","type":"function"},{"doc":"Returns boolean indicating whether pfx is a valid prefix/0 or not. Examples iex&gt; valid? ( % Pfx { bits : &lt;&lt; 1 , 2 , 3 , 4 &gt;&gt; , maxlen : 32 } ) true # bits exceed maxlen iex&gt; valid? ( % Pfx { bits : &lt;&lt; 1 , 2 , 3 , 4 &gt;&gt; , maxlen : 16 } ) false iex&gt; valid? ( { { 1 , 2 , 3 , 4 } , 24 } ) true iex&gt; valid? ( { 1 , 2 , 3 , 4 } ) true iex&gt; valid? ( &quot;1.2.3.4&quot; ) true iex&gt; valid? ( &quot;1.2.3.4/8&quot; ) true","ref":"Pfx.html#valid?/1","title":"Pfx.valid?/1","type":"function"},{"doc":"An :inet IPv4 or IPv6 address (tuple)","ref":"Pfx.html#t:ip_address/0","title":"Pfx.ip_address/0","type":"type"},{"doc":"An IPv4 prefix ({ t:inet.ip4_address/0 , 0..32}) or an IPv6 prefix ({ t:inet.ip6_address/0 , 0..128}).","ref":"Pfx.html#t:ip_prefix/0","title":"Pfx.ip_prefix/0","type":"type"},{"doc":"A prefix expressed as either a Pfx.t/0 struct, an IP address-tuple, an address,length-tuple or a CIDR string.","ref":"Pfx.html#t:prefix/0","title":"Pfx.prefix/0","type":"type"},{"doc":"A prefix struct with fields: bits and maxlen .","ref":"Pfx.html#t:t/0","title":"Pfx.t/0","type":"type"},{"doc":"README Online Pfx Documentation . Functions to make working with prefixes easier, especially IPv4 and IPv6 prefixes. Pfx defines a prefix as a struct with a number of bits and a maximum maxlen length. Hence a Pfx struct represents some domain-specific value, like an IPv4/6 address or network, a MAC address, a MAC OUI range or something else entirely. A Pfx struct can be created from: a bitstring/0 and a non_neg_integer/0 for the maximum length, a Pfx.ip_address/0 , a Pfx.ip_prefix/0 , or a binary/0 denoting an IP prefix in CIDR-notation. The first option allows for the creation of any sort of prefix, the latter three yield either an IPv4 or IPv6 prefix. Several functions, like Pfx.unique_local?/1 are more IP oriented, and are included along with the more generic Pfx functions (like Pfx.cut/3 ) in order to have one module to rule them all. Functions generally accept all four representations and yield their result in the same fashion, if possible: iex&gt; hosts ( &quot;10.10.10.0/30&quot; ) [ &quot;10.10.10.0&quot; , &quot;10.10.10.1&quot; , &quot;10.10.10.2&quot; , &quot;10.10.10.3&quot; ] iex&gt; hosts ( { { 10 , 10 , 10 , 0 } , 30 } ) [ { { 10 , 10 , 10 , 0 } , 32 } , { { 10 , 10 , 10 , 1 } , 32 } , { { 10 , 10 , 10 , 2 } , 32 } , { { 10 , 10 , 10 , 3 } , 32 } ] iex&gt; hosts ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 0 :: 6 &gt;&gt; , maxlen : 32 } ) [ % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 0 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 1 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 2 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 3 &gt;&gt; , maxlen : 32 } , ] # adopt representation of first argument iex&gt; band ( { 10 , 10 , 10 , 1 } , &quot;255.255.255.0&quot; ) { 10 , 10 , 10 , 0 } iex&gt; multicast? ( &quot;ff00::1&quot; ) true","ref":"readme.html","title":"README","type":"extras"},{"doc":"The Pfx.new/2 function will silently clip the provided bits -string to maxlen -bits when needed, since a Pfx struct named pfx is valid, iff: bit_size(pfx.bits) &lt;= pfx.maxlen , and where pfx.maxlen is a non_neg_integer/0 Keep that in mind when instantiating directly or updating a Pfx , otherwise functions will choke on it. Same goes for Pfx.ip_address/0 representations, which must be a valid :inet.ip_address() , representing either an IPv4 or IPv6 address through a tuple of four 8 -bit wide numbers or eight 16 -bit wide numbers. If used as the first element in a Pfx.ip_prefix/0 tuple, the second element is interpreted as the mask, used to clip the bitstring when creating the Pfx struct. IPv4 masks must be in range 0..32 and IPv6 masks in range 0..128 . The resulting Pfx will have its maxlen set to 32 for IPv4 tuples and 128 for IPv6 tuples. Last but not least, a binary is interpreted as a string in CIDR-notation for some IPv4/IPv6 address or prefix.","ref":"readme.html#validity","title":"README - Validity","type":"extras"},{"doc":"Pfx.new/1 accepts CIDR-strings which are ultimately processed using erlang's :inet.parse_address which, at the time of writing, still honors the ancient linux tradition of injecting zero's when presented with less than four IPv4 digits in a CIDR string. # &quot;d&quot; -&gt; &quot;0.0.0.d&quot; iex&gt; new ( &quot;10&quot; ) |&gt; format ( ) &quot;0.0.0.10&quot; iex&gt; new ( &quot;10/8&quot; ) |&gt; format ( ) &quot;0.0.0.0/8&quot; # &quot;d1.d2&quot; -&gt; &quot;d1.0.0.d2&quot; iex&gt; new ( &quot;10.10&quot; ) |&gt; format ( ) &quot;10.0.0.10&quot; iex&gt; new ( &quot;10.10/16&quot; ) |&gt; format ( ) &quot;10.0.0.0/16&quot; # &quot;d1.d2.d3&quot; -&gt; &quot;d1.d2.0.d3&quot; iex&gt; new ( &quot;10.10.10&quot; ) |&gt; format ( ) &quot;10.10.0.10&quot; iex&gt; new ( &quot;10.10.10/24&quot; ) |&gt; format ( ) &quot;10.10.0.0/24&quot; Bottom line: never go short, you may be unpleasantly surprised.","ref":"readme.html#ancient-tradition","title":"README - Ancient tradition","type":"extras"},{"doc":"A lot of Pfx -functions convert the Pfx.bits bitstring to an integer using Pfx.cast/1 , before performing some, often Bitwise -related, calculation on them. Luckily Elixir can handle pretty large numbers which seem mostly limited by the available system memory. Other functions, like Pfx.digits/2 return a tuple with numbers and are so limited by the maximum number of elements in a tuple (~16M+). So if you're taking this somewhere far, far away, heed these limitations before leaving. Also, everything is done in Elixir with no extra, external dependencies. Usually fast enough, but if you really feel the need for speed, you might want to look elsewhere. Ayway, enough downplay, here are some more examples.","ref":"readme.html#limitations","title":"README - Limitations","type":"extras"},{"doc":"# IANA&#39;s OUI range 00-00-5e-xx-xx-xx iex&gt; new ( &lt;&lt; 0x00 , 0x00 , 0x5e &gt;&gt; , 48 ) % Pfx { bits : &lt;&lt; 0 , 0 , 94 &gt;&gt; , maxlen : 48 } # IANA&#39;s assignment for the VRRP MAC address range 00-00-5e-00-01-{VRID} iex&gt; vrrp_mac_range = new ( &lt;&lt; 0x00 , 0x00 , 0x5e , 0x00 , 0x01 &gt;&gt; , 48 ) % Pfx { bits : &lt;&lt; 0 , 0 , 94 , 0 , 1 &gt;&gt; , maxlen : 48 } iex&gt; iex&gt; vrrp_mac = new ( &lt;&lt; 0x00 , 0x00 , 0x5e , 0x00 , 0x01 , 0x0f &gt;&gt; , 48 ) % Pfx { bits : &lt;&lt; 0 , 0 , 94 , 0 , 1 , 15 &gt;&gt; , maxlen : 48 } iex&gt; iex&gt; member? ( vrrp_mac , vrrp_mac_range ) true iex&gt; cut ( vrrp_mac , 47 , - 8 ) |&gt; cast ( ) 15 # IPv4 examples iex&gt; new ( &lt;&lt; 10 , 10 , 10 &gt;&gt; , 32 ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } iex&gt; new ( &quot;10.10.10.0/24&quot; ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } iex&gt; new ( { 10 , 10 , 10 , 10 } ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 10 &gt;&gt; , maxlen : 32 } iex&gt; new ( { { 10 , 10 , 10 , 10 } , 24 } ) % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } # IPv6 examples iex&gt; new ( &lt;&lt; 44252 :: 16 , 6518 :: 16 &gt;&gt; , 128 ) % Pfx { bits : &lt;&lt; 0xACDC :: 16 , 0x1976 :: 16 &gt;&gt; , maxlen : 128 } iex&gt; new ( &quot;acdc:1976::/32&quot; ) % Pfx { bits : &lt;&lt; 44252 :: 16 , 6518 :: 16 &gt;&gt; , maxlen : 128 } iex&gt; new ( { { 44252 , 6518 , 0 , 0 , 0 , 0 , 0 , 0 } , 32 } ) % Pfx { bits : &lt;&lt; 0xACDC :: 16 , 0x1976 :: 16 &gt;&gt; , maxlen : 128 } Pfx.t/0 implements the String.Chars protocol with some defaults for prefixes that formats prefixes with: maxlen: 32 as an IPv4 CIDR string, maxlen: 48 as a MAC address string and maxlen: 128 as an IPv6 CIDR string Other maxlen 's will simply come out as a series of 8-bit numbers joined by &quot;.&quot; followed by /num_of_bits . The latter is omitted if equal to pfx.bits length. If other formatting is required, use the Pfx.format/2 function, which takes some options that help shape the string representation for a Pfx struct. # a subnet iex&gt; &quot; \#{ new ( &lt;&lt; 10 , 11 , 12 &gt;&gt; , 32 ) } &quot; &quot;10.11.12.0/24&quot; # an address iex&gt; &quot; \#{ new ( &lt;&lt; 10 , 11 , 12 , 13 &gt;&gt; , 32 ) } &quot; &quot;10.11.12.13&quot; # an ipv6 prefix iex&gt; &quot; \#{ new ( &lt;&lt; 0xACDC :: 16 , 0x1976 :: 16 &gt;&gt; , 128 ) } &quot; &quot;acdc:1976:0:0:0:0:0:0/32&quot; # a MAC address iex&gt; &quot; \#{ new ( &lt;&lt; 0xA1 , 0xB2 , 0xC3 , 0xD4 , 0xE5 , 0xF6 &gt;&gt; , 48 ) } &quot; &quot;A1:B2:C3:D4:E5:F6&quot; # just 8-bit numbers and mask length iex&gt; &quot; \#{ new ( &lt;&lt; 1 , 2 , 3 , 4 , 5 &gt;&gt; , 64 ) } &quot; &quot;1.2.3.4.5.0.0.0/40&quot; # an ip4 address formatted as a string of bits iex&gt; new ( &lt;&lt; 1 , 2 , 3 , 4 &gt;&gt; , 32 ) |&gt; format ( width : 1 , unit : 8 ) &quot;00000001.00000010.00000011.00000100&quot; A Pfx.t/0 struct is also enumerable: iex&gt; pfx = new ( &quot;10.10.10.0/30&quot; ) iex&gt; for ip &lt;- pfx do &quot; \#{ ip } &quot; end [ &quot;10.10.10.0&quot; , &quot;10.10.10.1&quot; , &quot;10.10.10.2&quot; , &quot;10.10.10.3&quot; ] Functions are sometimes IP specific, like: iex&gt; dns_ptr ( &quot;acdc:1975::b1ba:2021&quot; ) &quot;1.2.0.2.a.b.1.b.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.5.7.9.1.c.d.c.a.ip6.arpa&quot; iex&gt; teredo ( &quot;2001:0000:4136:e378:8000:63bf:3fff:fdd2&quot; ) %{ server : &quot;65.54.227.120&quot; , client : &quot;192.0.2.45&quot; , port : 40000 , flags : { 1 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } , prefix : &quot;2001:0000:4136:e378:8000:63bf:3fff:fdd2&quot; } But most of the times, functions have generic names, since they apply to all sorts of prefixes, e.g. iex&gt; partition ( % Pfx { bits : &lt;&lt; 10 , 10 , 10 &gt;&gt; , maxlen : 32 } , 26 ) [ % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 0 :: size ( 2 ) &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 1 :: size ( 2 ) &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 2 :: size ( 2 ) &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 10 , 10 , 10 , 3 :: size ( 2 ) &gt;&gt; , maxlen : 32 } ] The Pfx.new/1 and Pfx.new/2 always return a Pfx.t/0 struct, but most other functions will return their results in the same representation they were given. So the above could also be done as: iex&gt; partition ( &quot;10.10.10.0/24&quot; , 26 ) [ &quot;10.10.10.0/26&quot; , &quot;10.10.10.64/26&quot; , &quot;10.10.10.128/26&quot; , &quot;10.10.10.192/26&quot; ] # or iex&gt; partition ( { { 10 , 10 , 10 , 0 } , 24 } , 26 ) [ { { 10 , 10 , 10 , 0 } , 26 } , { { 10 , 10 , 10 , 64 } , 26 } , { { 10 , 10 , 10 , 128 } , 26 } , { { 10 , 10 , 10 , 192 } , 26 } ]","ref":"readme.html#examples","title":"README - Examples","type":"extras"},{"doc":"Pfx can be installed by adding pfx to your list of dependencies in mix.exs : def deps do [ { :pfx , &quot;~&gt; 0.1.1&quot; } ] end","ref":"readme.html#installation","title":"README - Installation","type":"extras"},{"doc":"CHANGELOG 0.1.1 fixed brot, rotating empty pfx.bits fixed band, result has same number of bits as its first argument fixed bor, result has same number of bits as its first argument fixed bxor, result has same number of bits as its first argument fixed contrast, 1.2.3.0/24 is really to the left of 1.2.4.0/24 IPv6 addresses in lowercase 0.1.0 initial version","ref":"changelog.html","title":"CHANGELOG","type":"extras"}]